.. toctree::
   :maxdepth: 3
   :caption: Contents:

Introduction
============

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

Reference guide
===============

AWS API Gateway
---------------

.. automodule:: awsmate.apigateway
   :members:
   :show-inheritance:

AWS Lambda Function
-------------------

.. automodule:: awsmate.lambdafunction
   :members:
   :show-inheritance:

AWS S3
------

.. automodule:: awsmate.s3
   :members:
   :show-inheritance:

Logger
------

.. automodule:: awsmate.logger
   :members:
   :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
